Index: src/parsing/parser.h |
diff --git a/src/parsing/parser.h b/src/parsing/parser.h |
index 5cefdc79b9bb123310135c3ad19ba4a9029a9fe9..20c79371822276d08a8b1691a4855a9fb090ad59 100644 |
--- a/src/parsing/parser.h |
+++ b/src/parsing/parser.h |
@@ -222,17 +222,16 @@ |
void DeserializeScopeChain(ParseInfo* info, |
MaybeHandle<ScopeInfo> maybe_outer_scope_info); |
- // Handle errors detected during parsing |
- void ReportErrors(Isolate* isolate, Handle<Script> script); |
- // Move statistics to Isolate |
- void UpdateStatistics(Isolate* isolate, Handle<Script> script); |
+ // Handle errors detected during parsing, move statistics to Isolate, |
+ // internalize strings (move them to the heap). |
+ void Internalize(Isolate* isolate, Handle<Script> script, bool error); |
void HandleSourceURLComments(Isolate* isolate, Handle<Script> script); |
private: |
friend class ParserBase<Parser>; |
friend class v8::internal::ExpressionClassifier<ParserTypes<Parser>>; |
- friend bool v8::internal::parsing::ParseProgram(ParseInfo*, bool); |
- friend bool v8::internal::parsing::ParseFunction(ParseInfo*, bool); |
+ friend bool v8::internal::parsing::ParseProgram(ParseInfo*); |
+ friend bool v8::internal::parsing::ParseFunction(ParseInfo*); |
bool AllowsLazyParsingWithoutUnresolvedVariables() const { |
return scope()->AllowsLazyParsingWithoutUnresolvedVariables( |